==> libgnomedb-1.3.4.tar.gz: libgnomedb-1.3.4/libgnomedb/gnome-db-dbms-update-viewer.h <==
/* gnome-db-dbms-update-viewer.h
 *
 * Copyright (C) 2002 Vivien Malerba
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#ifndef __GNOME_DB_DBMS_UPDATE_VIEWER__
#define __GNOME_DB_DBMS_UPDATE_VIEWER__

#include <gtk/gtk.h>
#include "gnome-db-dict.h"

G_BEGIN_DECLS

#define GNOME_DB_DBMS_UPDATE_VIEWER_TYPE          (gnome_db_dbms_update_viewer_get_type())
#define GNOME_DB_DBMS_UPDATE_VIEWER(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, gnome_db_dbms_update_viewer_get_type(), GnomeDbmsUpdateViewer)
#define GNOME_DB_DBMS_UPDATE_VIEWER_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, gnome_db_dbms_update_viewer_get_type (), GnomeDbmsUpdateViewerClass)
#define IS_GNOME_DB_DBMS_UPDATE_VIEWER(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gnome_db_dbms_update_viewer_get_type ())


typedef struct _GnomeDbmsUpdateViewer      GnomeDbmsUpdateViewer;
typedef struct _GnomeDbmsUpdateViewerClass GnomeDbmsUpdateViewerClass;
typedef struct _GnomeDbmsUpdateViewerPriv  GnomeDbmsUpdateViewerPriv;


/* struct for the object's data */
struct _GnomeDbmsUpdateViewer
{
	GtkVBox             object;

	GnomeDbmsUpdateViewerPriv *priv;
};

/* struct for the object's class */
struct _GnomeDbmsUpdateViewerClass
{
	GtkVBoxClass        parent_class;
};

/* 
 * Generic widget's methods 
*/
GType      gnome_db_dbms_update_viewer_get_type            (void);
GtkWidget *gnome_db_dbms_update_viewer_new                 (GnomeDbDict *dict);

/*
 * Widget's manipulations
 */
void       gnome_db_dbms_update_viewer_reset               (GnomeDbmsUpdateViewer *mgv);

G_END_DECLS

#endif

==> libgnomedb-1.99.1.tar.gz: libgnomedb-1.99.1/libgnomedb/gnome-db-dbms-update-viewer.h <==
/* gnome-db-dbms-update-viewer.h
 *
 * Copyright (C) 2002 - 2005 Vivien Malerba
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#ifndef __GNOME_DB_DBMS_UPDATE_VIEWER__
#define __GNOME_DB_DBMS_UPDATE_VIEWER__

#include <gtk/gtk.h>
#include <libgda/gda-decl.h>

G_BEGIN_DECLS

#define GNOME_DB_TYPE_DBMS_UPDATE_VIEWER          (gnome_db_dbms_update_viewer_get_type())
#define GNOME_DB_DBMS_UPDATE_VIEWER(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, gnome_db_dbms_update_viewer_get_type(), GnomeDbmsUpdateViewer)
#define GNOME_DB_DBMS_UPDATE_VIEWER_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, gnome_db_dbms_update_viewer_get_type (), GnomeDbmsUpdateViewerClass)
#define IS_GNOME_DB_DBMS_UPDATE_VIEWER(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gnome_db_dbms_update_viewer_get_type ())


typedef struct _GnomeDbmsUpdateViewer      GnomeDbmsUpdateViewer;
typedef struct _GnomeDbmsUpdateViewerClass GnomeDbmsUpdateViewerClass;
typedef struct _GnomeDbmsUpdateViewerPriv  GnomeDbmsUpdateViewerPriv;


/* struct for the object's data */
struct _GnomeDbmsUpdateViewer
{
	GtkVBox             object;

	GnomeDbmsUpdateViewerPriv *priv;
};

/* struct for the object's class */
struct _GnomeDbmsUpdateViewerClass
{
	GtkVBoxClass        parent_class;
};

/* 
 * Generic widget's methods 
*/
GType      gnome_db_dbms_update_viewer_get_type            (void);
GtkWidget *gnome_db_dbms_update_viewer_new                 (GdaDict *dict);

/*
 * Widget's manipulations
 */
void       gnome_db_dbms_update_viewer_reset               (GnomeDbmsUpdateViewer *mgv);

G_END_DECLS

#endif
